
privatize
=========
a package for turning class variables into parameters

<span style="white-space: nowrap;">
  <img src="https://img.shields.io/pypi/v/privatize" alt="version"/>
  <img src="https://img.shields.io/travis/com/lockhartlab/privatize/master"  alt="build-status-master"/>
  <img src="https://img.shields.io/codecov/c/github/lockhartlab/privatize/master" alt="coverage-master"/>
</span>

<hr>

note that this package is **still in development**  
version 1.0 will be the first major release  
until then, consider this code heavily volatile

yet, install simply by calling ```pip install privatize```

